@@ -1,19 +1,19 @@
 /*
  *  Copyright (C) 2015 Andrzej <ndrwrdck@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License
+ *  as published by the Free Software Foundation; either version 2
+ *  of the License, or (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 
@@ -56,7 +56,7 @@
 static void              pulseaudio_dialog_build                  (PulseaudioDialog          *dialog);
 static void              pulseaudio_dialog_help_button_clicked    (PulseaudioDialog          *dialog,
                                                                    GtkWidget                 *button);
-static void              pulseaudio_dialog_mixer_name_changed     (PulseaudioDialog          *dialog);
+static void              pulseaudio_dialog_mixer_command_changed     (PulseaudioDialog          *dialog);
 static void              pulseaudio_dialog_run_mixer              (PulseaudioDialog          *dialog,
                                                                    GtkWidget                 *widget);
 
@@ -98,7 +98,7 @@ pulseaudio_dialog_init (PulseaudioDialog *dialog)
 
 
 static void
-pulseaudio_dialog_mixer_name_changed (PulseaudioDialog *dialog)
+pulseaudio_dialog_mixer_command_changed (PulseaudioDialog *dialog)
 {
   GObject *object;
   gchar   *path;
@@ -108,7 +108,7 @@ pulseaudio_dialog_mixer_name_changed (PulseaudioDialog *dialog)
 
   object = gtk_builder_get_object (GTK_BUILDER (dialog), "button-run-mixer");
   g_return_if_fail (GTK_IS_BUTTON (object));
-  path = g_find_program_in_path (pulseaudio_config_get_mixer_name (dialog->config));
+  path = g_find_program_in_path (pulseaudio_config_get_mixer_command (dialog->config));
   gtk_widget_set_sensitive (GTK_WIDGET (object), path != NULL);
   g_free (path);
 }
@@ -119,17 +119,28 @@ static void
 pulseaudio_dialog_run_mixer (PulseaudioDialog *dialog,
                              GtkWidget        *widget)
 {
-  GError *error = NULL;
+  GError    *error = NULL;
+  GtkWidget *message_dialog;
 
   g_return_if_fail (IS_PULSEAUDIO_DIALOG (dialog));
   g_return_if_fail (GTK_IS_BUTTON (widget));
 
   if (!xfce_spawn_command_line_on_screen (gtk_widget_get_screen (widget),
-                                          pulseaudio_config_get_mixer_name (dialog->config),
+                                          pulseaudio_config_get_mixer_command (dialog->config),
                                           FALSE, FALSE, &error))
     {
-      xfce_dialog_show_error (NULL, error, _("Failed to execute command \"%s\"."),
-                              pulseaudio_config_get_mixer_name (dialog->config));
+      message_dialog = gtk_message_dialog_new_with_markup (NULL,
+                                                           GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                           GTK_MESSAGE_ERROR,
+                                                           GTK_BUTTONS_CLOSE,
+                                                           _("<big><b>Failed to execute command \"%s\".</b></big>\n\n%s"),
+                                                           pulseaudio_config_get_mixer_command (dialog->config),
+                                                           error->message);
+      gtk_window_set_title (GTK_WINDOW (message_dialog), _("Error"));
+      gtk_dialog_run (GTK_DIALOG (message_dialog));
+      gtk_widget_destroy (message_dialog);
+      //xfce_dialog_show_error (NULL, error, _("Failed to execute command \"%s\"."),
+      //                        pulseaudio_config_get_mixer_command (dialog->config));
       g_error_free (error);
     }
 }
@@ -171,18 +182,18 @@ pulseaudio_dialog_build (PulseaudioDialog *dialog)
                               G_OBJECT (object), "active",
                               G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
 
-      object = gtk_builder_get_object (builder, "entry-mixer-name");
+      object = gtk_builder_get_object (builder, "entry-mixer-command");
       g_return_if_fail (GTK_IS_ENTRY (object));
-      g_object_bind_property (G_OBJECT (dialog->config), "mixer-name",
+      g_object_bind_property (G_OBJECT (dialog->config), "mixer-command",
                               G_OBJECT (object), "text",
                               G_BINDING_SYNC_CREATE | G_BINDING_BIDIRECTIONAL);
 
       object = gtk_builder_get_object (builder, "button-run-mixer");
       g_return_if_fail (GTK_IS_BUTTON (object));
-      g_signal_connect_swapped (G_OBJECT (dialog->config), "notify::mixer-name",
-                                G_CALLBACK (pulseaudio_dialog_mixer_name_changed),
+      g_signal_connect_swapped (G_OBJECT (dialog->config), "notify::mixer-command",
+                                G_CALLBACK (pulseaudio_dialog_mixer_command_changed),
                                 dialog);
-      pulseaudio_dialog_mixer_name_changed (dialog);
+      pulseaudio_dialog_mixer_command_changed (dialog);
       g_signal_connect_swapped (G_OBJECT (object), "clicked",
                                 G_CALLBACK (pulseaudio_dialog_run_mixer), dialog);
 
