@@ -29,6 +29,7 @@
 #include <gtk/gtk.h>
 #include <libxfce4panel/libxfce4panel.h>
 #include <libxfce4util/libxfce4util.h>
+#include <libxfce4ui/libxfce4ui.h>
 
 #include "pulseaudio-menu.h"
 #include "scalemenuitem.h"
@@ -62,12 +63,9 @@ static void
 pulseaudio_menu_class_init (PulseaudioMenuClass *klass)
 {
   GObjectClass      *gobject_class;
-  GtkWidgetClass    *gtkwidget_class;
 
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = pulseaudio_menu_finalize;
-
-  gtkwidget_class = GTK_WIDGET_CLASS (klass);
 }
 
 
@@ -76,9 +74,11 @@ static void
 pulseaudio_menu_init (PulseaudioMenu *menu)
 {
   menu->volume                         = NULL;
+  menu->config                         = NULL;
   menu->button                         = NULL;
   menu->range_output                   = NULL;
   menu->mute_output_item               = NULL;
+  menu->volume_changed_id              = 0;
 }
 
 
@@ -89,6 +89,16 @@ pulseaudio_menu_finalize (GObject *object)
 
   menu = PULSEAUDIO_MENU (object);
 
+  if (menu->volume_changed_id != 0)
+    g_signal_handler_disconnect (G_OBJECT (menu->volume), menu->volume_changed_id);
+
+  menu->volume                         = NULL;
+  menu->config                         = NULL;
+  menu->button                         = NULL;
+  menu->range_output                   = NULL;
+  menu->mute_output_item               = NULL;
+  menu->volume_changed_id              = 0;
+
   G_OBJECT_CLASS (pulseaudio_menu_parent_class)->finalize (object);
 }
 
@@ -200,9 +210,6 @@ pulseaudio_menu_new (PulseaudioVolume *volume,
   GdkScreen      *gscreen;
   GtkWidget      *mi;
   GtkWidget      *img = NULL;
-  GdkPixbuf      *pix;
-  GtkIconInfo    *info;
-  GtkStyleContext *context;
 
   g_return_val_if_fail (IS_PULSEAUDIO_VOLUME (volume), NULL);
   g_return_val_if_fail (IS_PULSEAUDIO_CONFIG (config), NULL);
@@ -227,15 +234,9 @@ pulseaudio_menu_new (PulseaudioVolume *volume,
   /* output volume slider */
   mi = scale_menu_item_new_with_range (0.0, 100.0, 1.0);
 
-  /* attempt to load and display the brightness icon */
-  context = gtk_widget_get_style_context (GTK_WIDGET (mi));
-  info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (), "audio-volume-high-symbolic", 24, GTK_ICON_LOOKUP_GENERIC_FALLBACK);
-  pix = gtk_icon_info_load_symbolic_for_context (info, context, NULL, NULL);
-  if (pix)
-    {
-      img = gtk_image_new_from_pixbuf (pix);
-      gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), img);
-    }
+  img = gtk_image_new_from_icon_name ("audio-volume-high-symbolic", GTK_ICON_SIZE_DND);
+  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (mi), img);
+  gtk_image_set_pixel_size (GTK_IMAGE (img), 24);
 
   scale_menu_item_set_description_label (SCALE_MENU_ITEM (mi), _("<b>Audio output volume</b>"));
 
@@ -262,7 +263,7 @@ pulseaudio_menu_new (PulseaudioVolume *volume,
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
 
   /* Audio mixers */
-  mi = gtk_menu_item_new_with_mnemonic (_("_Run audio mixer..."));
+  mi = gtk_menu_item_new_with_mnemonic (_("_Audio mixer..."));
   gtk_widget_show (mi);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
   g_signal_connect_swapped (G_OBJECT (mi), "activate", G_CALLBACK (pulseaudio_menu_run_audio_mixer), menu);
