@@ -44,10 +44,6 @@ static gboolean scale_menu_item_button_release_event    (GtkWidget          *men
                                                          GdkEventButton     *event);
 static gboolean scale_menu_item_motion_notify_event     (GtkWidget          *menuitem,
                                                          GdkEventMotion     *event);
-static gboolean scale_menu_item_grab_broken             (GtkWidget          *menuitem,
-                                                         GdkEventGrabBroken *event);
-static void     scale_menu_item_grab_notify             (GtkWidget          *menuitem,
-                                                         gboolean            was_grabbed);
 static void     scale_menu_item_parent_set              (GtkWidget          *item,
                                                          GtkWidget          *previous_parent);
 static void     update_packing                          (ScaleMenuItem  *    self);
@@ -108,8 +104,6 @@ scale_menu_item_class_init (ScaleMenuItemClass *item_class)
   widget_class->button_press_event   = scale_menu_item_button_press_event;
   widget_class->button_release_event = scale_menu_item_button_release_event;
   widget_class->motion_notify_event  = scale_menu_item_motion_notify_event;
-  widget_class->grab_broken_event    = scale_menu_item_grab_broken;
-  widget_class->grab_notify          = scale_menu_item_grab_notify;
   widget_class->parent_set           = scale_menu_item_parent_set;
 
 
@@ -308,7 +302,6 @@ scale_menu_item_button_release_event (GtkWidget      *menuitem,
   if (priv->grabbed)
     {
       priv->grabbed = FALSE;
-      scale_menu_item_grab_broken (menuitem, NULL);
       g_signal_emit (menuitem, signals[SLIDER_RELEASED], 0);
     }
 
@@ -344,38 +337,6 @@ scale_menu_item_motion_notify_event (GtkWidget      *menuitem,
   return TRUE;
 }
 
-static void
-scale_menu_item_grab_notify (GtkWidget *menuitem,
-                             gboolean   was_grabbed)
-{
-  ScaleMenuItemPrivate *priv;
-
-  TRACE("entering");
-
-  g_return_if_fail (IS_SCALE_MENU_ITEM (menuitem));
-
-  priv = GET_PRIVATE (menuitem);
-
-  GTK_WIDGET_GET_CLASS (priv->scale)->grab_notify (priv->scale, was_grabbed);
-}
-
-static gboolean
-scale_menu_item_grab_broken (GtkWidget          *menuitem,
-                             GdkEventGrabBroken *event)
-{
-  ScaleMenuItemPrivate *priv;
-
-  g_return_val_if_fail (IS_SCALE_MENU_ITEM (menuitem), FALSE);
-
-  priv = GET_PRIVATE (menuitem);
-
-  TRACE("entering");
-
-  GTK_WIDGET_GET_CLASS (priv->scale)->grab_broken_event (priv->scale, event);
-
-  return TRUE;
-}
-
 static void
 menu_hidden (GtkWidget     *menu,
              ScaleMenuItem *scale)
